"use client";

import { useEffect, useMemo, useTransition } from "react";

import FormBuilder from "@/components/FormBuilder/form-builder";
import AutocompleteField from "@/components/FormBuilder/FormFields/autocomplete-field";
import InputField from "@/components/FormBuilder/FormFields/input-field";
import useFormBuilder from "@/components/FormBuilder/hooks/use-form-builder";
import prepareFields from "@/components/FormBuilder/utils/prepare-fields";
import Yup from "@/components/FormBuilder/utils/yup";
import { updateUserInfo } from "@/servers/actions/userinfo-action";
import Cookies from "js-cookie";
import { Loader2 } from "lucide-react";
import { useTranslations } from "next-intl";
import { toast } from "sonner";

export default function AccountForm({ userInfo, refetch, imageFile }: { userInfo: any, refetch: any, imageFile: File | null }) {
	const t = useTranslations("UserAccount.FormAccount");
	const [isPending, startTransition] = useTransition();

	useEffect(() => {
		if (userInfo) {
			const { first_name, middle_name, last_name, address, email } = userInfo;
			FormHooks.reset({
				first_name, middle_name: middle_name ?? "", last_name, address, email: email ?? "",
				language: Cookies.get("NEXT_LOCALE") === "ar" ? "ar" : "en",
			});

		}
	}, [userInfo]);

	const fields = useMemo(
		() =>
			prepareFields({
				first_name: {
					yup: Yup.string().required(t("validation.firstName.required")),
					type: "input",
					component: InputField,
					componentProps: ({ }) => ({
						type: "text",
						label: t("Label.FirstName"),
						placeholder: t("Label.FirstName"),
						containerClassName: "col-span-6",
					}),
				},
				middle_name: {
					yup: Yup.string().nullable(),
					type: "input",
					component: InputField,
					componentProps: ({ }) => ({
						type: "text",
						label: t("Label.MiddleName"),
						placeholder: t("Label.MiddleName"),
						containerClassName: "col-span-6",
					}),
				},
				last_name: {
					yup: Yup.string().required(t("validation.lastName.required")),
					type: "input",
					component: InputField,
					componentProps: ({ }) => ({
						type: "text",
						label: t("Label.LastName"),
						placeholder: t("Label.LastName"),
						containerClassName: "col-span-6",
					}),
				},
				email: {
					yup: Yup.string().nullable(),
					type: "input",
					component: InputField,
					componentProps: ({ }) => ({
						type: "text",
						label: t("Label.Email"),
						placeholder: t("Label.Email"),
						containerClassName: "col-span-6",
					}),
				},
				address: {
					yup: Yup.string().required(t("validation.address.required")),
					type: "input",
					component: InputField,
					componentProps: ({ }) => ({
						type: "text",
						label: t("Label.Address"),
						placeholder: t("Label.Address"),
						containerClassName: "col-span-6",
					}),
				},

				language: {
					yup: Yup.string().optional(),
					type: "autocomplete",
					component: AutocompleteField,
					componentProps: {
						label: t("Label.Language"),
						containerClassName: "col-span-6",
						placeholder: t("SelectLanguage"),
						options: [
							{ value: "ar", label: t("Arabic") },
							{ value: "en", label: t("English") },
						],
					},
				},

			}),
		[t]
	);

	const FormHooks = useFormBuilder(fields, {
		defaultValues: {
			first_name: "",
			middle_name: "",
			last_name: "",
			email: "",
			address: "",
			language: "",
		},
	});

	async function onSubmit(data: any) {
		try {
			startTransition(async () => {
				const formData = new FormData();
				formData.append("first_name", data.first_name);
				formData.append("middle_name", data.middle_name);
				formData.append("last_name", data.last_name);
				formData.append("email", data.email);
				formData.append("address", data.address);
				if (imageFile) formData.append("image", imageFile);

				const result = await updateUserInfo(formData);
				if (result?.success) {
					toast.success(t("RequestSent"), {
						style: {
							backgroundColor: "green",
							color: "white",
						},
					});
					if (data?.language) {
						Cookies.set("NEXT_LOCALE", data.language);
					}
					await refetch();
				} else {
					if (Array.isArray(result?.message)) {
						result?.message?.map((error: any) => {
							toast.error(t(error.replace(".", "")));
						});
					}
					else toast.error(t(result?.message));
				}


			});
		} catch (error) {
			console.error("Registration error:", error);
			toast.error(t("Something went wrong"));
		}
	}

	return (
		<form onSubmit={FormHooks.handleSubmit(onSubmit)}>
			<div className="my-9 py-2 md:py-6">
				<p className="mb-6 text-center text-lg font-semibold leading-5 text-custom-fourth md:text-start md:text-base md:font-normal">
					{t("GeneralSettings")}
				</p>

				<div className="flex flex-col items-center justify-center gap-8 p-8">
					<FormBuilder fields={fields} FormHooks={FormHooks} />
					<div className="flex w-full items-center justify-center gap-4 md:justify-end">
						<button
							type="submit"
							className="text-center h-9 w-full max-w-[136px] rounded-sm bg-custom-accent text-[#F3F3F3] hover:bg-custom-accent"
							disabled={isPending}
						>
							{isPending ? <Loader2 className="mx-auto w-4 h-4 animate-spin" /> : t("Button.Submit")}
						</button>
					</div>
				</div>
			</div>
		</form>
	);
}
